==> flink-1.17.2-src.tgz: flink-1.17.2/flink-runtime/src/test/java/org/apache/flink/runtime/rest/messages/JobPlanInfoTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.runtime.rest.messages;

import org.apache.flink.runtime.jobgraph.JobGraph;
import org.apache.flink.runtime.jobgraph.JobGraphTestUtils;
import org.apache.flink.runtime.jobgraph.jsonplan.JsonPlanGenerator;

/** Tests that the {@link JobPlanInfo} can be marshalled and unmarshalled. */
public class JobPlanInfoTest extends RestResponseMarshallingTestBase<JobPlanInfo> {

    @Override
    protected Class<JobPlanInfo> getTestResponseClass() {
        return JobPlanInfo.class;
    }

    @Override
    protected JobPlanInfo getTestResponseInstance() {
        JobGraph jg = JobGraphTestUtils.emptyJobGraph();
        return new JobPlanInfo(JsonPlanGenerator.generatePlan(jg));
    }
}

==> flink-1.20.3-src.tgz: flink-1.20.3/flink-runtime/src/test/java/org/apache/flink/runtime/rest/messages/JobPlanInfoTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.runtime.rest.messages;

import org.apache.flink.runtime.jobgraph.JobGraph;
import org.apache.flink.runtime.jobgraph.JobGraphTestUtils;
import org.apache.flink.runtime.jobgraph.jsonplan.JsonPlanGenerator;
import org.apache.flink.testutils.junit.extensions.parameterized.NoOpTestExtension;

import org.junit.jupiter.api.extension.ExtendWith;

/** Tests that the {@link JobPlanInfo} can be marshalled and unmarshalled. */
@ExtendWith(NoOpTestExtension.class)
class JobPlanInfoTest extends RestResponseMarshallingTestBase<JobPlanInfo> {

    @Override
    protected Class<JobPlanInfo> getTestResponseClass() {
        return JobPlanInfo.class;
    }

    @Override
    protected JobPlanInfo getTestResponseInstance() {
        JobGraph jg = JobGraphTestUtils.emptyJobGraph();
        return new JobPlanInfo(JsonPlanGenerator.generatePlan(jg));
    }
}
